@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: UTF-8 -*-
 
-# Copyright (c) 2014-2018, Matthew Brennan Jones <matthew.brennan.jones@gmail.com>
+# Copyright (c) 2014-2019, Matthew Brennan Jones <matthew.brennan.jones@gmail.com>
 # Py-cpuinfo gets CPU info with pure Python 2 & 3
 # It uses the MIT License
 # It is hosted at: https://github.com/workhorsy/py-cpuinfo
@@ -63,6 +63,7 @@ from test_windows_8_x86_64 import TestWindows_8_X86_64
 from test_windows_10_x86_64 import TestWindows_10_X86_64
 from test_cpuid import TestCPUID
 from test_actual import TestActual
+from test_cli import TestCLI
 
 if __name__ == '__main__':
 	def logger(msg):
@@ -99,7 +100,8 @@ if __name__ == '__main__':
 		TestWindows_8_X86_64,
 		TestWindows_10_X86_64,
 		TestCPUID,
-		TestActual
+		TestActual,
+		TestCLI
 	]
 
 	# Add the tests to the suite
