@@ -364,7 +364,7 @@ class TestLinuxFedora_24_ppc64le(unittest.TestCase):
 		self.assertEqual(1, len(cpuinfo._get_cpu_info_from_ibm_pa_features()))
 		self.assertEqual(0, len(cpuinfo._get_cpu_info_from_sysinfo()))
 		self.assertEqual(0, len(cpuinfo._get_cpu_info_from_cpuid()))
-		self.assertEqual(14, len(cpuinfo.get_cpu_info()))
+		self.assertEqual(14, len(cpuinfo._get_cpu_info_internal()))
 
 	def test_get_cpu_info_from_lscpu(self):
 		info = cpuinfo._get_cpu_info_from_lscpu()
@@ -391,7 +391,7 @@ class TestLinuxFedora_24_ppc64le(unittest.TestCase):
 		self.assertEqual((3425000000, 0), info['hz_actual_raw'])
 
 	def test_all(self):
-		info = cpuinfo.get_cpu_info()
+		info = cpuinfo._get_cpu_info_internal()
 
 		self.assertEqual('POWER8E (raw), altivec supported', info['brand'])
 		self.assertEqual('3.4250 GHz', info['hz_advertised'])
